==> directfb_0.9.20.orig.tar.gz: DirectFB-0.9.20/gfxdrivers/cyber5k/cyber5k.h <==
/*
   (c) Copyright 2000-2002  convergence integrated media GmbH.
   (c) Copyright 2002       convergence GmbH.
   
   All rights reserved.

   Written by Denis Oliver Kropp <dok@directfb.org>,
              Andreas Hundt <andi@fischlustig.de> and
              Sven Neumann <sven@convergence.de>.

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the
   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#ifndef ___CYBER5K_H__
#define ___CYBER5K_H__

#include <asm/types.h>
#include <core/layers.h>

/* HACK */
extern volatile __u8 *cyber_mmio;


typedef struct {
     volatile __u8 *mmio_base;
} CyberDriverData;

typedef struct {
     /* state validation */
     int v_dst;
     int v_src;
     int v_color;
     int v_src_colorkey;
     int v_blitting_cmd;

     /* stored values */
     __u32 dst_pixeloffset;
     __u32 dst_pixelpitch;
     __u32 src_pixeloffset;
     __u32 src_pixelpitch;

     __u32 blitting_cmd;
} CyberDeviceData;


extern DisplayLayerFuncs cyberUnderlayFuncs;

#endif

==> directfb_0.9.22.orig.tar.gz: DirectFB-0.9.22/gfxdrivers/cyber5k/cyber5k.h <==
/*
   (c) Copyright 2000-2002  convergence integrated media GmbH.
   (c) Copyright 2002-2004  convergence GmbH.

   All rights reserved.

   Written by Denis Oliver Kropp <dok@directfb.org>,
              Andreas Hundt <andi@fischlustig.de>,
              Sven Neumann <neo@directfb.org> and
              Ville Syrjl <syrjala@sci.fi>.

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the
   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#ifndef ___CYBER5K_H__
#define ___CYBER5K_H__

#include <asm/types.h>
#include <core/layers.h>

/* HACK */
extern volatile __u8 *cyber_mmio;


typedef struct {
     volatile __u8 *mmio_base;
} CyberDriverData;

typedef struct {
     /* state validation */
     int v_dst;
     int v_src;
     int v_color;
     int v_src_colorkey;
     int v_blitting_cmd;

     /* stored values */
     __u32 dst_pixeloffset;
     __u32 dst_pixelpitch;
     __u32 src_pixeloffset;
     __u32 src_pixelpitch;

     __u32 blitting_cmd;
} CyberDeviceData;


extern DisplayLayerFuncs cyberUnderlayFuncs;

#endif
